@@ -1,6 +1,8 @@
-from .classifier import MLP, SVM, AdaBoost, Keras, RandomForest, Transformer
+from .classifier import (MLP, SVM, AdaBoost, Keras, RandomForest, Transformer,
+                         XGBoost)
 from .embedding import CountVectorizer, Doc2Vec, OneHot, Sequence, TfIdf
-from .linguistics import Contract, FindAll, Phrase, Snowball, Sub, Tokenize
+from .linguistics import (Contract, FindAll, Lemmatizer, Phrase, Snowball, Sub,
+                          Tokenize)
 from .multi import Merge
 from .preprocessing import Normalize
 from .reduction import NMF, PCA, SVD, UMAP
@@ -9,8 +11,7 @@ from .special import SplitHashtag
 __all__ = [
     "Tokenize", "Snowball", "Phrase", "Sub", "Contract", "FindAll",
     "TfIdf", "CountVectorizer", "Sequence", "OneHot", "Doc2Vec",
-    "SVD", "PCA", "NMF", "UMAP",
+    "SVD", "PCA", "NMF", "UMAP", "Lemmatizer",
     "RandomForest", "AdaBoost", "SVM", "MLP", "Keras", "Transformer",
-    "Merge", "Normalize",
-    "SplitHashtag"
+    "XGBoost", "Merge", "Normalize", "SplitHashtag"
 ]
